summaryrefslogtreecommitdiff
path: root/mutt
diff options
context:
space:
mode:
Diffstat (limited to 'mutt')
-rwxr-xr-xmutt/notmuch-hook.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/mutt/notmuch-hook.sh b/mutt/notmuch-hook.sh
index bc4867d..5af81b5 100755
--- a/mutt/notmuch-hook.sh
+++ b/mutt/notmuch-hook.sh
@@ -6,10 +6,10 @@ notmuch new
notmuch tag +inbox +unread -new -- tag:new
# tag all messages from "me" as sent
-notmuch tag +sent -inbox -- from:ben@bsima.me
+notmuch tag +sent -inbox -unread -- from:ben@bsima.me
-# tag TODOs from myself
-notmuch tag +todo -inbox -- subject:TODO
+# tag TODOs from myself, always mark as unread so I'm forced to process them
+notmuch tag +todo -inbox +unread -- subject:TODO or from:ben@bsima.me and to:ben@bsima.me
# tag some newsletters, but don't show them in inbox
notmuch tag +newsletters -inbox -- \